@@ -48,8 +48,6 @@ class BaseConnectionContactInfoInterface;
 class BaseConnectionAddressingInterface;
 class BaseConnectionAliasingInterface;
 class BaseConnectionAvatarsInterface;
-class BaseConnectionClientTypesInterface;
-class BaseConnectionContactCapabilitiesInterface;
 class BaseConnectionManager;
 class BaseProtocol;
 class BaseProtocolAddressingInterface;
@@ -59,7 +57,6 @@ class BaseChannel;
 class BaseChannelTextType;
 class BaseChannelCallType;
 class BaseChannelMessagesInterface;
-class BaseChannelFileTransferType;
 class BaseChannelRoomListType;
 class BaseChannelServerAuthenticationType;
 class BaseChannelSASLAuthenticationInterface;
@@ -94,8 +91,6 @@ typedef SharedPtr<BaseConnectionContactInfoInterface> BaseConnectionContactInfoI
 typedef SharedPtr<BaseConnectionAddressingInterface> BaseConnectionAddressingInterfacePtr;
 typedef SharedPtr<BaseConnectionAliasingInterface> BaseConnectionAliasingInterfacePtr;
 typedef SharedPtr<BaseConnectionAvatarsInterface> BaseConnectionAvatarsInterfacePtr;
-typedef SharedPtr<BaseConnectionClientTypesInterface> BaseConnectionClientTypesInterfacePtr;
-typedef SharedPtr<BaseConnectionContactCapabilitiesInterface> BaseConnectionContactCapabilitiesInterfacePtr;
 typedef SharedPtr<BaseConnectionManager> BaseConnectionManagerPtr;
 typedef SharedPtr<BaseProtocol> BaseProtocolPtr;
 typedef SharedPtr<BaseProtocolAddressingInterface> BaseProtocolAddressingInterfacePtr;
@@ -105,7 +100,6 @@ typedef SharedPtr<BaseChannel> BaseChannelPtr;
 typedef SharedPtr<BaseChannelCallType> BaseChannelCallTypePtr;
 typedef SharedPtr<BaseChannelTextType> BaseChannelTextTypePtr;
 typedef SharedPtr<BaseChannelMessagesInterface> BaseChannelMessagesInterfacePtr;
-typedef SharedPtr<BaseChannelFileTransferType> BaseChannelFileTransferTypePtr;
 typedef SharedPtr<BaseChannelRoomListType> BaseChannelRoomListTypePtr;
 typedef SharedPtr<BaseChannelServerAuthenticationType> BaseChannelServerAuthenticationTypePtr;
 typedef SharedPtr<BaseChannelSASLAuthenticationInterface> BaseChannelSASLAuthenticationInterfacePtr;
