@@ -1,3 +1,6 @@
+// We need to use the deprecated TpTextMixin here to test compatibility functionality
+#define _TP_IGNORE_DEPRECATIONS
+
 #include <tests/lib/test.h>
 
 #include <tests/lib/glib-helpers/test-conn-helper.h>
@@ -6,11 +9,11 @@
 #include <tests/lib/glib/echo/chan.h>
 #include <tests/lib/glib/echo2/chan.h>
 
-#include <TelepathyQt4/Connection>
-#include <TelepathyQt4/Message>
-#include <TelepathyQt4/PendingReady>
-#include <TelepathyQt4/ReceivedMessage>
-#include <TelepathyQt4/TextChannel>
+#include <TelepathyQt/Connection>
+#include <TelepathyQt/Message>
+#include <TelepathyQt/PendingReady>
+#include <TelepathyQt/ReceivedMessage>
+#include <TelepathyQt/TextChannel>
 
 #include <telepathy-glib/debug.h>
 
@@ -142,7 +145,7 @@ void TestTextChan::initTestCase()
 
     // create a Channel by magic, rather than doing D-Bus round-trips for it
     mTextChanPath = mConn->objectPath() + QLatin1String("/TextChannel");
-    QByteArray chanPath(mTextChanPath.toAscii());
+    QByteArray chanPath(mTextChanPath.toLatin1());
     mTextChanService = EXAMPLE_ECHO_CHANNEL(g_object_new(
                 EXAMPLE_TYPE_ECHO_CHANNEL,
                 "connection", mConn->service(),
@@ -151,15 +154,13 @@ void TestTextChan::initTestCase()
                 NULL));
 
     mMessagesChanPath = mConn->objectPath() + QLatin1String("/MessagesChannel");
-    chanPath = mMessagesChanPath.toAscii();
+    chanPath = mMessagesChanPath.toLatin1();
     mMessagesChanService = EXAMPLE_ECHO_2_CHANNEL(g_object_new(
                 EXAMPLE_TYPE_ECHO_2_CHANNEL,
                 "connection", mConn->service(),
                 "object-path", chanPath.data(),
                 "handle", handle,
                 NULL));
-
-    tp_handle_unref(mContactRepo, handle);
 }
 
 void TestTextChan::init()
@@ -231,7 +232,7 @@ void TestTextChan::commonTest(bool withMessages)
                     SIGNAL(finished(Tp::PendingOperation *)),
                     SLOT(expectFailure(Tp::PendingOperation *))));
         QCOMPARE(mLoop->exec(), 0);
-        QCOMPARE(mLastError, TP_QT4_ERROR_NOT_IMPLEMENTED);
+        QCOMPARE(mLastError, TP_QT_ERROR_NOT_IMPLEMENTED);
         QVERIFY(!mLastErrorMessage.isEmpty());
     }
 
@@ -331,6 +332,13 @@ void TestTextChan::commonTest(bool withMessages)
                 static_cast<uint>(Tp::MessagePartSupportFlagOneAttachment |
                     Tp::MessagePartSupportFlagMultipleAttachments));
         QCOMPARE(mChan->deliveryReportingSupport(), DeliveryReportingSupportFlagReceiveFailures);
+        QCOMPARE(mChan->supportedMessageTypes().size(), 3);
+        // Supports normal, action, notice
+        QVERIFY(mChan->supportsMessageType(Tp::ChannelTextMessageTypeNormal));
+        QVERIFY(mChan->supportsMessageType(Tp::ChannelTextMessageTypeAction));
+        QVERIFY(mChan->supportsMessageType(Tp::ChannelTextMessageTypeNotice));
+        QVERIFY(!mChan->supportsMessageType(Tp::ChannelTextMessageTypeAutoReply));
+        QVERIFY(!mChan->supportsMessageType(Tp::ChannelTextMessageTypeDeliveryReport));
     } else {
         QCOMPARE(mChan->supportedContentTypes(), QStringList() << QLatin1String("text/plain"));
         QCOMPARE(static_cast<uint>(mChan->messagePartSupport()), 0U);
@@ -491,7 +499,7 @@ void TestTextChan::commonTest(bool withMessages)
         QCOMPARE(r.deliveryDetails().error(), Tp::ChannelTextSendErrorPermissionDenied);
         QVERIFY(r.deliveryDetails().hasDebugMessage());
         QCOMPARE(r.deliveryDetails().debugMessage(), QLatin1String("You asked for it"));
-        QCOMPARE(r.deliveryDetails().dbusError(), TP_QT4_ERROR_PERMISSION_DENIED);
+        QCOMPARE(r.deliveryDetails().dbusError(), TP_QT_ERROR_PERMISSION_DENIED);
         QVERIFY(r.deliveryDetails().hasEchoedMessage());
         QCOMPARE(r.deliveryDetails().echoedMessage().text(), QLatin1String("Three (fail)"));
 
